summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAkim Demaille <demaille@gostai.com>2012-02-19 12:54:09 +0100
committerAkim Demaille <demaille@gostai.com>2012-02-19 18:26:01 +0100
commit14f4455e4323ea2e232f7c47f3c0b10ea084f6d6 (patch)
treeb0f859735c815a71baffdc6f2cf6b390f924537b
parent43e9e2a113dd4c30e304e5130cfca83ea704c14e (diff)
downloadbison-14f4455e4323ea2e232f7c47f3c0b10ea084f6d6.tar.gz
maint: address sc_prohibit_doubled_word.
* data/yacc.c, doc/bison.texinfo: Reword to avoid having to disable that check. * cfg.mk: No longer skip this test. (cherry picked from commit 762caaf6393d71d740ad86855a15f5000721d103) Conflicts: data/yacc.c
-rw-r--r--cfg.mk1
-rw-r--r--data/yacc.c20
-rw-r--r--doc/bison.texinfo2
3 files changed, 11 insertions, 12 deletions
diff --git a/cfg.mk b/cfg.mk
index 358631d9..b21383e7 100644
--- a/cfg.mk
+++ b/cfg.mk
@@ -41,7 +41,6 @@ local-checks-to-skip = \
sc_immutable_NEWS \
sc_prohibit_always_true_header_tests \
sc_prohibit_atoi_atof \
- sc_prohibit_doubled_word \
sc_prohibit_strcmp
# The local directory containing the checked-out copy of gnulib used in
diff --git a/doc/bison.texinfo b/doc/bison.texinfo
index 329d81d0..3e9333aa 100644
--- a/doc/bison.texinfo
+++ b/doc/bison.texinfo
@@ -4092,7 +4092,7 @@ In references, in order to specify names containing dots and dashes, an explicit
bracketed syntax @code{$[name]} and @code{@@[name]} must be used:
@example
@group
-if-stmt: IF '(' expr ')' THEN then.stmt ';'
+if-stmt: "if" '(' expr ')' "then" then.stmt ';'
@{ $[if-stmt] = new_if_stmt ($expr, $[then.stmt]); @}
@end group
@end example
diff --git a/data/yacc.c b/data/yacc.c
index d18b2698..96eea2a8 100644
--- a/data/yacc.c
+++ b/data/yacc.c
@@ -534,20 +534,20 @@ union yyalloc
#endif
#if defined YYCOPY_NEEDED && YYCOPY_NEEDED
/* Copy COUNT objects from FROM to TO. The source and destination do
not overlap. */
# ifndef YYCOPY
# if defined __GNUC__ && 1 < __GNUC__
-# define YYCOPY(To, From, Count) \
- __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
+# define YYCOPY(Dst, Src, Count) \
+ __builtin_memcpy (Dst, Src, (Count) * sizeof (*(Src)))
# else
-# define YYCOPY(To, From, Count) \
- do \
- { \
- YYSIZE_T yyi; \
- for (yyi = 0; yyi < (Count); yyi++) \
- (To)[yyi] = (From)[yyi]; \
- } \
+# define YYCOPY(Dst, Src, Count) \
+ do \
+ { \
+ YYSIZE_T yyi; \
+ for (yyi = 0; yyi < (Count); yyi++) \
+ (Dst)[yyi] = (Src)[yyi]; \
+ } \
while (YYID (0))
# endif
# endif
@@ -534,20 +534,20 @@ union yyalloc
#endif
#if defined YYCOPY_NEEDED && YYCOPY_NEEDED
-/* Copy COUNT objects from FROM to TO. The source and destination do
+/* Copy COUNT objects from SRC to DST. The source and destination do
not overlap. */
# ifndef YYCOPY